<?php

namespace SGalinski\SgNews\Xclass;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Xclass for the page renderer to add the possibility to dynamically replace data in the head
 */
class PageRenderer extends \TYPO3\CMS\Core\Page\PageRenderer {
	/**
	 * @var array
	 */
	protected $headerDataRegex = [];

	/**
	 * Adds header data regular expression possibilities for USER_INT objects
	 *
	 * @param string $pattern
	 * @param string $replacement
	 * @return void
	 */
	public function addHeaderDataRegex($pattern, $replacement) {
		$this->headerDataRegex[] = [
			'pattern' => $pattern,
			'replacement' => $replacement,
		];
	}

	/**
	 * Executes the header regular expressions
	 *
	 * @return void
	 */
	protected function executeHeaderRegularExpressions() {
		$this->headerData = implode(LF, $this->headerData);
		if (is_array($this->headerDataRegex)) {
			foreach ($this->headerDataRegex as $regex) {
				$this->headerData = preg_replace(
					'/' . $regex['pattern'] . '/is',
					$regex['replacement'],
					$this->headerData
				);
			}
		}
		$this->headerData = explode(LF, $this->headerData);
	}

	/**
	 * Executes the header regular expressions for uncached objects
	 *
	 * @param string $cachedPageContent
	 * @param string $substituteHash
	 * @return string
	 */
	public function renderJavaScriptAndCssForProcessingOfUncachedContentObjects(
		$cachedPageContent,
		$substituteHash
	): string {
		$this->executeHeaderRegularExpressions();
		return parent::renderJavaScriptAndCssForProcessingOfUncachedContentObjects($cachedPageContent, $substituteHash);
	}

	/**
	 *  Executes the header regular expressions for cached objects
	 *
	 * @param integer $part Section which should be rendered: self::PART_COMPLETE, self::PART_HEADER or self::PART_FOOTER
	 * @return string Content of rendered section
	 */
	public function render($part = self::PART_COMPLETE): string {
		$this->executeHeaderRegularExpressions();
		return parent::render($part);
	}
}
